@@ -229,15 +229,16 @@ class Interp(VirtualMachine):
         try_stmt: KW_TRY code_block else_from_try?;
         """
         kid = self.set_cur_ast(jac_ast)
+        self._jac_try_mode += 1
         try:
             self.run_code_block(kid[1])
-            return
         except TryException as e:
             if len(kid) > 2:
                 self.run_else_from_try(kid[2], e.ref)
         except Exception as e:
             if len(kid) > 2:
                 self.run_else_from_try(kid[2], self.jac_exception(e, kid[2]))
+        self._jac_try_mode -= 1
 
     def run_else_from_try(self, jac_ast, jac_ex):
         """
